@@ -1,8 +1,8 @@
-/** 
+/**
  * @file libgcmd-widget-factory.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2022 Uwe Scholz\n
+ * @copyright (C) 2013-2023 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -113,23 +113,21 @@ GtkWidget *create_directory_chooser_button (GtkWidget *parent, const gchar *name
 
 GtkWidget *create_file_chooser_button (GtkWidget *parent, const gchar *name, const gchar *value);
 
-GtkWidget *create_clist (GtkWidget *parent, const gchar *name, gint cols, gint rowh, GtkSignalFunc on_row_selected, GtkSignalFunc on_row_moved);
+GtkWidget *create_treeview (GtkWidget *parent, const gchar *name, GtkTreeModel *model, gint rowh, GtkSignalFunc on_selection_changed, GtkSignalFunc on_rows_reordered);
 
-void create_clist_column (GtkWidget *sw, gint col, gint width, const gchar *label);
+void create_treeview_column (GtkWidget *sw, gint col, gint width, const gchar *label);
 
 GtkWidget *create_vbuttonbox (GtkWidget *parent);
 
 GtkWidget *create_hbuttonbox (GtkWidget *parent);
 
-GtkWidget *create_combo (GtkWidget *parent);
+GtkWidget *create_combo_box_text_with_entry (GtkWidget *parent);
 
-GtkWidget *create_combo_new (GtkWidget *parent);
+GtkWidget *create_combo_box_text (GtkWidget *parent, const gchar **items);
 
-GtkWidget *create_option_menu (GtkWidget *parent, const gchar **items);
-
-inline const gchar *get_combo_text (GtkWidget *combo)
+inline const gchar *get_combo_box_entry_text (GtkWidget *combo)
 {
-    return gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry));
+    return gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo))));
 }
 
 inline GSList *get_radio_group (GtkWidget *radio)
@@ -159,8 +157,6 @@ GtkWidget *create_progress_bar (GtkWidget *parent);
 
 GtkWidget *create_sw (GtkWidget *parent);
 
-void progress_bar_update (GtkWidget *pbar, gint max);
-
 const char *get_entry_text (GtkWidget *parent, const gchar *entry_name);
 
 #ifdef __GNUC__
@@ -168,3 +164,26 @@ const char *get_entry_text (GtkWidget *parent, const gchar *entry_name);
 #else
     void create_error_dialog (const gchar *msg, ...);
 #endif
+
+#if !GTK_CHECK_VERSION(3,0,0)
+inline void gtk_progress_bar_set_show_text (GtkProgressBar *pbar, gboolean show_text)
+{
+    gtk_progress_bar_set_text (pbar, nullptr);
+    pbar->progress.show_text = show_text;
+}
+
+inline GtkWidget *gtk_tree_view_column_get_button (GtkTreeViewColumn *tree_column)
+{
+    return tree_column->button;
+}
+
+inline gboolean gtk_tree_model_iter_previous (GtkTreeModel *tree_model, GtkTreeIter *iter)
+{
+    GtkTreePath *path = gtk_tree_model_get_path (tree_model, iter);
+    gboolean result = gtk_tree_path_prev (path);
+    if (result)
+        result = gtk_tree_model_get_iter (tree_model, iter, path);
+    gtk_tree_path_free (path);
+    return result;
+}
+#endif
