@@ -2,7 +2,7 @@
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
     Copyright (C) 2007-2012 Piotr Eljasiak
-    Copyright (C) 2013-2022 Uwe Scholz
+    Copyright (C) 2013-2023 Uwe Scholz
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include "file-roller-small.xpm"
 
 #define NAME "File Roller Plugin"
-#define COPYRIGHT "Copyright \n\xc2\xa9 2003-2006 Marcus Bjurman\n\xc2\xa9 2013-2022 Uwe Scholz"
+#define COPYRIGHT "Copyright \n\xc2\xa9 2003-2006 Marcus Bjurman\n\xc2\xa9 2013-2023 Uwe Scholz"
 #define AUTHOR "Marcus Bjurman <marbj499@student.liu.se>"
 #define TRANSLATOR_CREDITS "Translations: https://l10n.gnome.org/module/gnome-commander/"
 #define WEBPAGE "https://gcmd.github.io"
@@ -42,7 +42,7 @@
 static PluginInfo plugin_nfo = {
     GNOME_CMD_PLUGIN_SYSTEM_CURRENT_VERSION,
     NAME,
-    VERSION,
+    PACKAGE_VERSION,
     COPYRIGHT,
     nullptr,
     nullptr,
@@ -383,7 +383,7 @@ static void on_add_to_archive (GtkMenuItem *item, FileRollerPlugin *plugin)
         hbox = gtk_hbox_new (FALSE, 6);
         g_object_ref (hbox);
         gtk_widget_show (hbox);
-        gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, FALSE, TRUE, 6);
+        gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), hbox, FALSE, TRUE, 6);
 
         entry = gtk_entry_new ();
         g_object_ref (entry);
@@ -415,7 +415,7 @@ static void on_add_to_archive (GtkMenuItem *item, FileRollerPlugin *plugin)
 
 
         pixbuf = gdk_pixbuf_new_from_xpm_data ((const char**)file_roller_xpm);
-        gtk_image_set_from_pixbuf (GTK_IMAGE (GTK_MESSAGE_DIALOG (dialog)->image), pixbuf);
+        gtk_image_set_from_pixbuf (GTK_IMAGE (gtk_message_dialog_get_image (GTK_MESSAGE_DIALOG (dialog))), pixbuf);
         g_object_unref (pixbuf);
 
         ret = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -620,7 +620,7 @@ static void configure (GnomeCmdPlugin *plugin)
     label = create_label (dialog, _("Default archive type"));
     table_add (table, label, 0, 1, (GtkAttachOptions) 0);
 
-    combo = create_combo_new (dialog);
+    combo = create_combo_box_text_with_entry (dialog);
     g_signal_connect (G_OBJECT(combo), "changed", G_CALLBACK (on_date_format_update), dialog);
     table_add (table, combo, 1, 1, GTK_FILL);
 
