@@ -2,7 +2,7 @@
  * @file gnome-cmd-make-copy-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2022 Uwe Scholz\n
+ * @copyright (C) 2013-2023 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -68,7 +68,22 @@ static gboolean on_ok (GnomeCmdStringDialog *string_dialog, const gchar **values
         return FALSE;
     }
 
-    copy_file (dialog->priv->f, dialog->priv->dir, filename);
+    if (filename[0] == '/')
+    {
+        gchar *parent_dir = g_path_get_dirname (filename);
+        gchar *dest_fn = g_path_get_basename (filename);
+
+        auto con = gnome_cmd_dir_get_connection (dialog->priv->dir);
+        auto conPath = gnome_cmd_con_create_path (con, parent_dir);
+        auto dir = gnome_cmd_dir_new (con, conPath);
+        delete conPath;
+        g_free (parent_dir);
+
+        copy_file (dialog->priv->f, dir, dest_fn);
+        g_free (dest_fn);
+    }
+    else
+        copy_file (dialog->priv->f, dialog->priv->dir, filename);
 
     return TRUE;
 }
