@@ -2,7 +2,7 @@
  * @file gnome-cmd-manage-bookmarks-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2022 Uwe Scholz\n
+ * @copyright (C) 2013-2023 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -234,7 +234,7 @@ static GtkWidget *create_view_and_model ()
     GtkTreeViewColumn *col = NULL;
 
     col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (bm_view), renderer, COL_GROUP, _("Group"));
-    gtk_widget_set_tooltip_text (col->button, _("Bookmark group"));
+    gtk_widget_set_tooltip_text (gtk_tree_view_column_get_button (col), _("Bookmark group"));
 
     g_object_set (renderer,
                   "weight-set", TRUE,
@@ -242,10 +242,10 @@ static GtkWidget *create_view_and_model ()
                   NULL);
 
     col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (bm_view), renderer, COL_NAME, _("Name"));
-    gtk_widget_set_tooltip_text (col->button, _("Bookmark name"));
+    gtk_widget_set_tooltip_text (gtk_tree_view_column_get_button (col), _("Bookmark name"));
 
     col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (bm_view), renderer, COL_SHORTCUT, _("Shortcut"));
-    gtk_widget_set_tooltip_text (col->button, _("Keyboard shortcut for selected bookmark"));
+    gtk_widget_set_tooltip_text (gtk_tree_view_column_get_button (col), _("Keyboard shortcut for selected bookmark"));
 
     g_object_set (renderer,
                   "foreground-set", TRUE,
@@ -253,7 +253,7 @@ static GtkWidget *create_view_and_model ()
                   NULL);
 
     col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (bm_view), renderer, COL_PATH, _("Path"));
-    gtk_widget_set_tooltip_text (col->button, _("Bookmarked path"));
+    gtk_widget_set_tooltip_text (gtk_tree_view_column_get_button (col), _("Bookmarked path"));
 
     g_object_set (renderer,
                   "foreground-set", TRUE,
