@@ -2,7 +2,7 @@
  * @file gnome-cmd-dir.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2022 Uwe Scholz\n
+ * @copyright (C) 2013-2023 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -540,9 +540,8 @@ static void create_list_progress_dialog (GnomeCmdDir *dir)
     dir->label = create_label (dir->dialog, _("Waiting for file list"));
 
     dir->pbar = create_progress_bar (dir->dialog);
-    gtk_progress_set_show_text (GTK_PROGRESS (dir->pbar), FALSE);
-    gtk_progress_set_activity_mode (GTK_PROGRESS (dir->pbar), TRUE);
-    gtk_progress_configure (GTK_PROGRESS (dir->pbar), 0, 0, DIR_PBAR_MAX);
+    gtk_progress_bar_set_show_text (GTK_PROGRESS_BAR (dir->pbar), FALSE);
+    gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (dir->pbar), 1.0 / (gdouble) DIR_PBAR_MAX);
 
     gtk_box_pack_start (GTK_BOX (vbox), dir->label, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vbox), dir->pbar, FALSE, TRUE, 0);
@@ -790,6 +789,8 @@ GFile *gnome_cmd_dir_get_absolute_path_gfile (GnomeCmdDir *dir, string absolute_
 
     if (uriScheme && strcmp (uriScheme, "smb") == 0)
     {
+        g_object_ref (dir_gFile);
+
         while (get_gfile_attribute_uint32(dir_gFile, G_FILE_ATTRIBUTE_STANDARD_TYPE) == G_FILE_TYPE_DIRECTORY)
         {
             auto gFileParent = g_file_get_parent(dir_gFile);
@@ -800,11 +801,11 @@ GFile *gnome_cmd_dir_get_absolute_path_gfile (GnomeCmdDir *dir, string absolute_
         auto server_and_share = g_file_get_uri(dir_gFile);
         stringify (absolute_filename, g_build_filename (server_and_share, absolute_filename.c_str(), nullptr));
         g_free (server_and_share);
+
+        g_object_unref (dir_gFile);
     }
 
     g_free(uriScheme);
-
-    g_object_unref (dir_gFile);
 #endif
 
     GnomeCmdPath *path = gnome_cmd_con_create_path (dir->priv->con, absolute_filename.c_str());
@@ -968,7 +969,9 @@ void gnome_cmd_dir_file_changed (GnomeCmdDir *dir, const gchar *uri_str)
     GnomeCmdFile *f = dir->priv->file_collection->find(uri_str);
 
     if (f == nullptr)
+    {
         return;
+    }
 
     dir->priv->needs_mtime_update = TRUE;
 
