@@ -2,7 +2,7 @@
  * @file gnome-cmd-file-selector.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2022 Uwe Scholz\n
+ * @copyright (C) 2013-2023 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -374,7 +374,7 @@ static void create_con_buttons (GnomeCmdFileSelector *fs)
         g_object_set_data (G_OBJECT (btn), "con", con);
         g_signal_connect (btn, "button-press-event", (GtkSignalFunc) on_con_btn_clicked, fs);
         gtk_box_pack_start (GTK_BOX (fs->con_btns_hbox), btn, FALSE, FALSE, 0);
-        GTK_WIDGET_UNSET_FLAGS (btn, GTK_CAN_FOCUS);
+        gtk_widget_set_can_focus (btn, FALSE);
         fs->priv->old_btns = g_list_append (fs->priv->old_btns, btn);
         gtk_widget_set_tooltip_text (btn, gnome_cmd_con_get_go_text (con));
 
@@ -385,13 +385,13 @@ static void create_con_buttons (GnomeCmdFileSelector *fs)
 
         if (pm)
         {
-            GtkWidget *pixmap = gtk_pixmap_new (pm->pixmap, pm->mask);
-            if (pixmap)
+            GtkWidget *image = gtk_image_new_from_pixmap (pm->pixmap, pm->mask);
+            if (image)
             {
-                g_object_ref (pixmap);
-                g_object_set_data_full (*fs, "con-pixmap", pixmap, g_object_unref);
-                gtk_widget_show (pixmap);
-                gtk_box_pack_start (GTK_BOX (hbox), pixmap, TRUE, TRUE, 0);
+                g_object_ref (image);
+                g_object_set_data_full (*fs, "con-image", image, g_object_unref);
+                gtk_widget_show (image);
+                gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 0);
             }
         }
 
@@ -800,15 +800,12 @@ static void init (GnomeCmdFileSelector *fs)
     }
 
     // create the connection combo
-    fs->con_combo = new GnomeCmdCombo(2, 1);
+    GtkListStore *store = gtk_list_store_new (3, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_POINTER);
+    fs->con_combo = GNOME_CMD_COMBO (gnome_cmd_combo_new_with_store(store, 2, 1, 2));
     g_object_ref (fs->con_combo);
     g_object_set_data_full (*fs, "con_combo", fs->con_combo, g_object_unref);
     gtk_widget_set_size_request (*fs->con_combo, max_string_size, -1);
-    gtk_clist_set_row_height (GTK_CLIST (fs->con_combo->list), 20);
-    gtk_entry_set_editable (GTK_ENTRY (fs->con_combo->entry), FALSE);
-    gtk_clist_set_column_width (GTK_CLIST (fs->con_combo->list), 0, 20);
-    gtk_clist_set_column_width (GTK_CLIST (fs->con_combo->list), 1, 60);
-    GTK_WIDGET_UNSET_FLAGS (fs->con_combo->button, GTK_CAN_FOCUS);
+    gtk_entry_set_editable (GTK_ENTRY (fs->con_combo->get_entry()), FALSE);
 
     // create the free space on volume label
     fs->vol_label = gtk_label_new ("");
@@ -1007,14 +1004,9 @@ void GnomeCmdFileSelector::update_connections()
     gboolean found_my_con = FALSE;
 
     con_combo->clear();
-    con_combo->highest_pixmap = 20;
-    con_combo->widest_pixmap = 20;
-    gtk_clist_set_row_height (GTK_CLIST (con_combo->list), 20);
-    gtk_clist_set_column_width (GTK_CLIST (con_combo->list), 0, 20);
 
     for (GList *l=gnome_cmd_con_list_get_all (gnome_cmd_con_list_get ()); l; l = l->next)
     {
-        gchar *text[3];
         auto con = static_cast<GnomeCmdCon*> (l->data);
 
 #ifdef HAVE_SAMBA
@@ -1027,18 +1019,10 @@ void GnomeCmdFileSelector::update_connections()
         if (con == get_connection())
             found_my_con = TRUE;
 
-        text[0] = nullptr;
-        text[1] = (gchar *) gnome_cmd_con_get_alias (con);
-        text[2] = nullptr;
-
         GnomeCmdPixmap *pixmap = gnome_cmd_con_get_go_pixmap (con);
 
         if (pixmap)
-        {
-            gint row = con_combo->append(text, con);
-
-            con_combo->set_pixmap(row, 0, pixmap);
-        }
+            con_combo->append((gchar *) gnome_cmd_con_get_alias (con), con, 0, pixmap->pixbuf, -1);
     }
 
     // If the connection is no longer available use the home connection
@@ -1106,38 +1090,67 @@ static gboolean on_new_textfile_ok (GnomeCmdStringDialog *string_dialog, const g
     GnomeCmdDir *dir = fs->get_directory();
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), TRUE);
 
-    auto uriBaseString = static_cast<gchar*>(GNOME_CMD_FILE (dir)->get_uri_str());
-    // Let the URI to the current directory end with '/'
-    auto conLastCharacter = uriBaseString[strlen(uriBaseString)-1];
-    auto uriBaseStringSep = conLastCharacter == G_DIR_SEPARATOR
-        ? g_strdup(uriBaseString)
-        : g_strdup_printf("%s%s", uriBaseString, G_DIR_SEPARATOR_S);
-    g_free (uriBaseString);
-
-    auto relativeFileNamePath = g_build_filename(".", fname, nullptr);
     GError *error = nullptr;
-    auto uriString = g_uri_resolve_relative (uriBaseStringSep, relativeFileNamePath,
-                                             G_URI_FLAGS_NONE, &error);
-    g_free(relativeFileNamePath);
-    g_free (uriBaseStringSep);
-    if (error)
+    GFile *gFile;
+
+    if (fname[0] == '/')
     {
-        gnome_cmd_string_dialog_set_error_desc (string_dialog, g_strdup_printf("%s", error->message));
-        g_error_free(error);
-        return FALSE;
+        auto con = gnome_cmd_dir_get_connection (dir);
+        auto conPath = gnome_cmd_con_create_path (con, fname);
+        gFile = gnome_cmd_con_create_gfile (con, conPath);
+        delete conPath;
+    }
+    else
+    {
+        auto uriBaseString = static_cast<gchar*>(GNOME_CMD_FILE (dir)->get_uri_str());
+        // Let the URI to the current directory end with '/'
+        auto conLastCharacter = uriBaseString[strlen(uriBaseString)-1];
+        auto uriBaseStringSep = conLastCharacter == G_DIR_SEPARATOR
+            ? g_strdup(uriBaseString)
+            : g_strdup_printf("%s%s", uriBaseString, G_DIR_SEPARATOR_S);
+        g_free (uriBaseString);
+
+        auto relativeFileNamePath = g_build_filename(".", fname, nullptr);
+        auto uriString = g_uri_resolve_relative (uriBaseStringSep, relativeFileNamePath,
+                                                 G_URI_FLAGS_NONE, &error);
+        g_free(relativeFileNamePath);
+        g_free (uriBaseStringSep);
+        if (error)
+        {
+            gnome_cmd_string_dialog_set_error_desc (string_dialog, g_strdup_printf("%s", error->message));
+            g_error_free(error);
+            return FALSE;
+        }
+
+        gFile = g_file_new_for_uri(uriString);
+        g_free (uriString);
     }
 
-    auto gFile = g_file_new_for_uri(uriString);
-    g_free (uriString);
     auto gFileOutputStream = g_file_create(gFile, G_FILE_CREATE_NONE, nullptr, &error);
     if (error)
     {
         gnome_cmd_string_dialog_set_error_desc (string_dialog, g_strdup_printf("%s", error->message));
         g_error_free(error);
+        g_object_unref (gFile);
         return FALSE;
     }
     g_object_unref(gFileOutputStream);
 
+    // focus the created file (if possible)
+    auto parentGFile = g_file_get_parent (gFile);
+    if (g_file_equal (parentGFile, gnome_cmd_dir_get_gfile (dir)))
+    {
+        gchar *uri_str = g_file_get_uri (gFile);
+        gnome_cmd_dir_file_created (dir, uri_str);
+        g_free (uri_str);
+        gchar *focus_filename = g_file_get_basename (gFile);
+        fs->file_list()->focus_file(focus_filename, TRUE);
+        g_free (focus_filename);
+    }
+    g_object_unref(parentGFile);
+
+    g_object_unref (gFile);
+
     return TRUE;
 }
 
@@ -1157,15 +1170,33 @@ static gboolean on_create_symlink_ok (GnomeCmdStringDialog *string_dialog, const
         return FALSE;
     }
 
-    auto gFile = gnome_cmd_dir_get_child_gfile (fs->get_directory(), fname);
+    GnomeCmdDir *dir = fs->get_directory();
+    g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), TRUE);
+
+    GFile *gFile;
+    if (fname[0] == '/')
+    {
+        auto con = gnome_cmd_dir_get_connection (dir);
+        auto conPath = gnome_cmd_con_create_path (con, fname);
+        gFile = gnome_cmd_con_create_gfile (con, conPath);
+        delete conPath;
+    }
+    else
+        gFile = gnome_cmd_dir_get_child_gfile (dir, fname);
     auto absolutePath = g_file_get_parse_name(fs->priv->sym_file->gFile);
 
     //if (g_file_make_symbolic_link (gFile, fs->priv->sym_file->get_uri_str(), nullptr, &error))
     if (g_file_make_symbolic_link (gFile, absolutePath, nullptr, &error))
     {
-        gchar *uri_str = g_file_get_uri (gFile);
-        gnome_cmd_dir_file_created (fs->get_directory(), uri_str);
-        g_free (uri_str);
+        auto parentGFile = g_file_get_parent (gFile);
+        if (g_file_equal (parentGFile, gnome_cmd_dir_get_gfile (dir)))
+        {
+            gchar *uri_str = g_file_get_uri (gFile);
+            gnome_cmd_dir_file_created (dir, uri_str);
+            g_free (uri_str);
+        }
+        g_object_unref(parentGFile);
+
         g_free(absolutePath);
         g_object_unref (gFile);
         return TRUE;
@@ -1535,15 +1566,15 @@ GtkWidget *GnomeCmdFileSelector::new_tab(GnomeCmdDir *dir, GnomeCmdFileList::Col
     g_signal_connect (fl, "dir-changed", G_CALLBACK (on_list_dir_changed), this);
     g_signal_connect (fl, "files-changed", G_CALLBACK (on_list_files_changed), this);
 
+    if (dir)
+        fl->set_connection(gnome_cmd_dir_get_connection (dir), dir);
+
     if (activate)
     {
         notebook->set_current_page(n);
         gtk_widget_grab_focus (*fl);
     }
 
-    if (dir)
-        fl->set_connection(gnome_cmd_dir_get_connection (dir), dir);
-
     g_signal_connect (fl, "file-clicked", G_CALLBACK (on_list_file_clicked), this);
     g_signal_connect (fl, "file-released", G_CALLBACK (on_list_file_released), this);
     g_signal_connect (fl, "list-clicked", G_CALLBACK (on_list_list_clicked), this);
@@ -1604,4 +1635,4 @@ GList* GnomeCmdFileSelector::GetTabs()
     GList *tabs = gtk_container_get_children (*this->notebook);
 
     return tabs;
-}
\ No newline at end of file
+}
