@@ -2,7 +2,7 @@
  * @file gnome-cmd-file.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2022 Uwe Scholz\n
+ * @copyright (C) 2013-2023 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -921,7 +921,7 @@ inline void do_view_file (GnomeCmdFile *f, gint internal_viewer=-1)
         case TRUE : {
                         GtkWidget *viewer = gviewer_window_file_view (f);
                         gtk_widget_show (viewer);
-                        gdk_window_set_icon (viewer->window, nullptr,
+                        gdk_window_set_icon (gtk_widget_get_window (viewer), nullptr,
                                              IMAGE_get_pixmap (PIXMAP_INTERNAL_VIEWER),
                                              IMAGE_get_mask (PIXMAP_INTERNAL_VIEWER));
                     }
@@ -1046,6 +1046,13 @@ void GnomeCmdFile::update_gFileInfo(GFileInfo *gFileInfo_new)
 
 gboolean GnomeCmdFile::is_local()
 {
+    if (!has_parent_dir (this))
+    {
+        if (GNOME_CMD_IS_DIR (this))
+            return gnome_cmd_dir_is_local (GNOME_CMD_DIR (this));
+        g_assert ("Non directory file without owning directory");
+    }
+
     return gnome_cmd_dir_is_local (::get_parent_dir (this));
 }
 
