@@ -2,7 +2,7 @@
  * @file gnome-cmd-main-win.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2022 Uwe Scholz\n
+ * @copyright (C) 2013-2023 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -167,7 +167,7 @@ static gint gnome_cmd_key_snooper(GtkWidget *grab_widget, GdkEventKey *event, Gn
         return FALSE;
     }
 
-    if (!GTK_WIDGET_HAS_FOCUS (GTK_WIDGET (fs->file_list())))
+    if (!gtk_widget_has_focus (GTK_WIDGET (fs->file_list())))
     {
         return FALSE;
     }
@@ -320,49 +320,67 @@ static void create_toolbar (GnomeCmdMainWin *mw)
 
 static void slide_set_100_0 (GtkMenu *menu, gpointer user_data)
 {
+    GtkAllocation main_win_allocation;
+    gtk_widget_get_allocation (GTK_WIDGET (main_win), &main_win_allocation);
+
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned),
-                            gnome_cmd_data.horizontal_orientation ? GTK_WIDGET (main_win)->allocation.height :
-                                                              GTK_WIDGET (main_win)->allocation.width);
+                            gnome_cmd_data.horizontal_orientation ? main_win_allocation.height :
+                                                              main_win_allocation.width);
 }
 
 
 static void slide_set_80_20 (GtkMenu *menu, gpointer user_data)
 {
+    GtkAllocation main_win_allocation;
+    gtk_widget_get_allocation (GTK_WIDGET (main_win), &main_win_allocation);
+
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned),
-                            gnome_cmd_data.horizontal_orientation ? (int)(GTK_WIDGET (main_win)->allocation.height*0.8f) :
-                                                              (int)(GTK_WIDGET (main_win)->allocation.width*0.8f));
+                            gnome_cmd_data.horizontal_orientation ? (int)(main_win_allocation.height*0.8f) :
+                                                              (int)(main_win_allocation.width*0.8f));
 }
 
 
 static void slide_set_60_40 (GtkMenu *menu, gpointer user_data)
 {
+    GtkAllocation main_win_allocation;
+    gtk_widget_get_allocation (GTK_WIDGET (main_win), &main_win_allocation);
+
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned),
-                            gnome_cmd_data.horizontal_orientation ? (int)(GTK_WIDGET (main_win)->allocation.height*0.6f) :
-                                                              (int)(GTK_WIDGET (main_win)->allocation.width*0.6f));
+                            gnome_cmd_data.horizontal_orientation ? (int)(main_win_allocation.height*0.6f) :
+                                                              (int)(main_win_allocation.width*0.6f));
 }
 
 
 static void slide_set_50_50 (GtkMenu *menu, gpointer user_data)
 {
+    GtkAllocation main_win_allocation;
+    gtk_widget_get_allocation (GTK_WIDGET (main_win), &main_win_allocation);
+
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned),
-                            gnome_cmd_data.horizontal_orientation ? (int)(GTK_WIDGET (main_win)->allocation.height*0.5f) :
-                                                              (int)(GTK_WIDGET (main_win)->allocation.width*0.5f));
+                            gnome_cmd_data.horizontal_orientation ? (int)(main_win_allocation.height*0.5f) :
+                                                              (int)(main_win_allocation.width*0.5f));
 }
 
 
 static void slide_set_40_60 (GtkMenu *menu, gpointer user_data)
 {
+    GtkAllocation main_win_allocation;
+    gtk_widget_get_allocation (GTK_WIDGET (main_win), &main_win_allocation);
+
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned),
-                            gnome_cmd_data.horizontal_orientation ? (int)(GTK_WIDGET (main_win)->allocation.height*0.4f) :
-                                                              (int)(GTK_WIDGET (main_win)->allocation.width*0.4f));
+                            gnome_cmd_data.horizontal_orientation ? (int)(main_win_allocation.height*0.4f) :
+                                                              (int)(main_win_allocation.width*0.4f));
 }
 
 
 static void slide_set_20_80 (GtkMenu *menu, gpointer user_data)
 {
+    GtkAllocation main_win_allocation;
+    gtk_widget_get_allocation (GTK_WIDGET (main_win), &main_win_allocation);
+
     gtk_paned_set_position (GTK_PANED (main_win->priv->paned),
-                            gnome_cmd_data.horizontal_orientation ? (int)(GTK_WIDGET (main_win)->allocation.height*0.2f) :
-                                                              (int)(GTK_WIDGET (main_win)->allocation.width*0.2f));
+                            gnome_cmd_data.horizontal_orientation ? (int)(main_win_allocation.height*0.2f) :
+                                                              (int)(main_win_allocation.width*0.2f));
 }
 
 
@@ -527,7 +545,7 @@ static gboolean on_slide_button_press (GtkWidget *widget, GdkEventButton *event,
         GtkPaned *paned = GTK_PANED (mw->priv->paned);
 
         // Check that the handle was clicked and not one of the children
-        if (paned->handle == event->window)
+        if (gtk_paned_get_handle_window (paned) == event->window)
         {
             gtk_menu_popup (GTK_MENU (create_slide_popup ()), NULL, NULL, NULL, NULL, event->button, event->time);
             return TRUE;
@@ -552,7 +570,7 @@ static void on_main_win_realize (GtkWidget *widget, GnomeCmdMainWin *mw)
         // g_free (dpath);
     // }
 
-    gdk_window_set_icon (GTK_WIDGET (mw)->window, NULL, IMAGE_get_pixmap (PIXMAP_LOGO), IMAGE_get_mask (PIXMAP_LOGO));
+    gdk_window_set_icon (gtk_widget_get_window (GTK_WIDGET (mw)), NULL, IMAGE_get_pixmap (PIXMAP_LOGO), IMAGE_get_mask (PIXMAP_LOGO));
 }
 
 
@@ -643,7 +661,7 @@ void GnomeCmdMainWin::update_drop_con_button(GnomeCmdFileList *fl)
         return;
 
     GnomeCmdPixmap *pm = NULL;
-    static GtkWidget *prev_pixmap = NULL;
+    static GtkWidget *prev_widget = NULL;
 
     GnomeCmdCon *con = fl->con;
     if (!con)
@@ -655,10 +673,10 @@ void GnomeCmdMainWin::update_drop_con_button(GnomeCmdFileList *fl)
     GtkWidget *btn = priv->tb_con_drop_btn;
     g_return_if_fail (GTK_IS_TOOL_BUTTON (btn));
 
-    if (prev_pixmap)
+    if (prev_widget)
     {
-        gtk_widget_destroy (prev_pixmap);
-        prev_pixmap = nullptr;
+        gtk_widget_destroy (prev_widget);
+        prev_widget = nullptr;
     }
 
     if (gnome_cmd_con_is_closeable (con))
@@ -674,13 +692,13 @@ void GnomeCmdMainWin::update_drop_con_button(GnomeCmdFileList *fl)
 
     if (pm)
     {
-        GtkWidget *pixmap = gtk_pixmap_new (pm->pixmap, pm->mask);
-        if (pixmap)
+        GtkWidget *image = gtk_image_new_from_pixmap (pm->pixmap, pm->mask);
+        if (image)
         {
-            g_object_ref (pixmap);
-            gtk_widget_show (pixmap);
-            gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON(btn), pixmap);
-            prev_pixmap = pixmap;
+            g_object_ref (image);
+            gtk_widget_show (image);
+            gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON(btn), image);
+            prev_widget = image;
         }
     }
     else
@@ -691,7 +709,7 @@ void GnomeCmdMainWin::update_drop_con_button(GnomeCmdFileList *fl)
             g_object_ref (label);
             gtk_widget_show (label);
             gtk_tool_button_set_label_widget(GTK_TOOL_BUTTON(btn), label);
-            prev_pixmap = label;
+            prev_widget = label;
         }
     }
 }
@@ -765,7 +783,7 @@ static gboolean on_window_state_event (GtkWidget *mw, GdkEventWindowState *event
         __attribute__ ((fallthrough));
 #endif
         default:            // other are usable
-            gdk_window_get_root_origin (mw->window, &x, &y);
+            gdk_window_get_root_origin (gtk_widget_get_window (mw), &x, &y);
             gnome_cmd_data_set_main_win_pos (x, y);
     }
 
@@ -793,6 +811,9 @@ static void destroy (GtkObject *object)
     if (main_win && main_win->advrename_dlg)
         gtk_widget_destroy (*main_win->advrename_dlg);
 
+    if (main_win && main_win->file_search_dlg)
+        gtk_widget_destroy (*main_win->file_search_dlg);
+
     gtk_main_quit ();
 }
 
@@ -835,6 +856,7 @@ static void init (GnomeCmdMainWin *mw)
     main_win = GNOME_CMD_MAIN_WIN (mw);
 
     mw->advrename_dlg = NULL;
+    mw->file_search_dlg = NULL;
     mw->priv = g_new0 (GnomeCmdMainWin::Private, 1);
     mw->priv->current_fs = LEFT;
     mw->priv->accel_group = gtk_accel_group_new ();
@@ -1018,6 +1040,9 @@ void GnomeCmdMainWin::update_style()
 
     if (gnome_cmd_data.cmdline_visibility)
         gnome_cmd_cmdline_update_style (GNOME_CMD_CMDLINE (priv->cmdline));
+
+    if (file_search_dlg)
+        file_search_dlg->update_style();
 }
 
 
