@@ -2,7 +2,7 @@
  * @file gnome-cmd-quicksearch-popup.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2022 Uwe Scholz\n
+ * @copyright (C) 2013-2023 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -134,8 +134,8 @@ static void on_text_changed (GtkEntry *entry, GnomeCmdQuicksearchPopup *popup)
 
 static gboolean on_key_pressed (GtkWidget *entry, GdkEventKey *event, GnomeCmdQuicksearchPopup *popup)
 {
-    if (GTK_ENTRY (entry)->editable && event->type == GDK_KEY_PRESS)
-        if (gtk_im_context_filter_keypress (GTK_ENTRY (entry)->im_context, event))
+    if (event->type == GDK_KEY_PRESS && gtk_editable_get_editable (GTK_EDITABLE (entry)))
+        if (gtk_entry_im_context_filter_keypress (GTK_ENTRY (entry), event))
             return TRUE;
 
     // While in quicksearch, treat "ALT/CTRL + key" as a simple "key"
@@ -226,8 +226,8 @@ inline void set_popup_position (GnomeCmdQuicksearchPopup *popup)
 
     gint x, y, w, h;
 
-    gdk_window_get_origin (wid->window, &x, &y);
-    gdk_drawable_get_size (wid->window, &w, &h);
+    gdk_window_get_origin (gtk_widget_get_window (wid), &x, &y);
+    gdk_drawable_get_size (gtk_widget_get_window (wid), &w, &h);
 
     y += h;
 
@@ -235,6 +235,22 @@ inline void set_popup_position (GnomeCmdQuicksearchPopup *popup)
 }
 
 
+static GObject *constructor (GType gtype, guint n_properties, GObjectConstructParam *properties)
+{
+    // change construct only properties
+    for (guint i = 0; i < n_properties; ++i)
+    {
+        gchar const *name = g_param_spec_get_name (properties[i].pspec);
+        if (!strcmp (name, "type"))
+        {
+            g_value_set_enum (properties[i].value, GTK_WINDOW_POPUP);
+            break;
+        }
+    }
+
+    return G_OBJECT_CLASS (parent_class)->constructor (gtype, n_properties, properties);
+}
+
 static void destroy (GtkObject *object)
 {
     GnomeCmdQuicksearchPopup *popup = GNOME_CMD_QUICKSEARCH_POPUP (object);
@@ -254,11 +270,13 @@ static void map (GtkWidget *widget)
 
 static void class_init (GnomeCmdQuicksearchPopupClass *klass)
 {
+    GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
     parent_class = (GtkWindowClass *) gtk_type_class (gtk_window_get_type ());
 
+    gobject_class->constructor = constructor;
     object_class->destroy = destroy;
     widget_class->map = ::map;
 }
@@ -332,7 +350,6 @@ GtkWidget *gnome_cmd_quicksearch_popup_new (GnomeCmdFileList *fl)
     GnomeCmdQuicksearchPopup *popup;
 
     popup = static_cast<GnomeCmdQuicksearchPopup*> (g_object_new (GNOME_CMD_TYPE_QUICKSEARCH_POPUP, nullptr));
-    GTK_WINDOW (popup)->type = GTK_WINDOW_POPUP;
     popup->priv->fl = fl;
     popup->priv->last_focused_file = nullptr;
     set_popup_position (popup);
