@@ -2,7 +2,7 @@
  * @file gnome-cmd-user-actions.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2022 Uwe Scholz\n
+ * @copyright (C) 2013-2023 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,6 +46,7 @@
 #include "dialogs/gnome-cmd-make-copy-dialog.h"
 #include "dialogs/gnome-cmd-manage-bookmarks-dialog.h"
 #include "dialogs/gnome-cmd-mkdir-dialog.h"
+#include "dialogs/gnome-cmd-search-dialog.h"
 #include "dialogs/gnome-cmd-options-dialog.h"
 #include "dialogs/gnome-cmd-prepare-copy-dialog.h"
 #include "dialogs/gnome-cmd-prepare-move-dialog.h"
@@ -736,7 +737,6 @@ void file_edit (GtkMenuItem *menuitem, gpointer not_used)
 	    command = g_strdup (gnome_cmd_data.options.editor);
 	    g_return_if_fail (command != nullptr);
 
-	    string dir_path;
 	    string cmd;
 
 	    cmd.reserve(2000);
@@ -748,14 +748,13 @@ void file_edit (GtkMenuItem *menuitem, gpointer not_used)
 	    }
 	    else
 	    {
-            GnomeCmdDir *dir = nullptr;
 	        gint     argc;
 	        gchar  **argv  = nullptr;
 	        GError  *error = nullptr;
 	        DEBUG ('g', "Edit file: %s\n", cmd.c_str());
 
 	        g_shell_parse_argv (cmd.c_str(), &argc, &argv, nullptr);
-	        if (!g_spawn_async (gnome_cmd_dir_is_local (dir) ? dir_path.c_str() : nullptr, argv, nullptr, G_SPAWN_SEARCH_PATH, nullptr, nullptr, nullptr, &error))
+	        if (!g_spawn_async (nullptr, argv, nullptr, G_SPAWN_SEARCH_PATH, nullptr, nullptr, nullptr, &error))
             gnome_cmd_error_message (_("Unable to execute command."), error);
 
 	        g_strfreev (argv);
@@ -772,30 +771,40 @@ void file_edit_new_doc (GtkMenuItem *menuitem, gpointer not_used)
 
 void file_search (GtkMenuItem *menuitem, gpointer not_used)
 {
-    string commandString;
-    commandString.reserve(2000);
-
-    if (parse_command(&commandString, (const gchar*) gnome_cmd_data.options.search) == 0)
+    if (gnome_cmd_data.options.use_internal_search)
     {
-	    DEBUG ('g', "Search command is empty.\n");
-	    gnome_cmd_show_message (*main_win, _("No search command given."), _("You can set a command for a search tool in the program options."));
-	    return;
+        if (!main_win->file_search_dlg)
+            main_win->file_search_dlg = new GnomeCmdSearchDialog(gnome_cmd_data.search_defaults);
+
+        main_win->file_search_dlg->show_and_set_focus();
     }
     else
     {
-        gint     argc;
-        gchar  **argv  = nullptr;
-        GError  *error = nullptr;
+        string commandString;
+        commandString.reserve(2000);
 
-        DEBUG ('g', "Invoking search: %s\n", commandString.c_str());
-        // put command into argv
-        g_shell_parse_argv (commandString.c_str(), &argc, &argv, nullptr);
-        // execute command
-        if (!g_spawn_async (nullptr, argv, nullptr, G_SPAWN_SEARCH_PATH, nullptr, nullptr, nullptr, &error))
+        if (parse_command(&commandString, (const gchar*) gnome_cmd_data.options.search) == 0)
         {
-            gnome_cmd_error_message (_("Unable to execute command."), error);
+            DEBUG ('g', "Search command is empty.\n");
+            gnome_cmd_show_message (*main_win, _("No search command given."), _("You can set a command for a search tool in the program options."));
+            return;
+        }
+        else
+        {
+            gint     argc;
+            gchar  **argv  = nullptr;
+            GError  *error = nullptr;
+
+            DEBUG ('g', "Invoking search: %s\n", commandString.c_str());
+            // put command into argv
+            g_shell_parse_argv (commandString.c_str(), &argc, &argv, nullptr);
+            // execute command
+            if (!g_spawn_async (nullptr, argv, nullptr, G_SPAWN_SEARCH_PATH, nullptr, nullptr, nullptr, &error))
+            {
+                gnome_cmd_error_message (_("Unable to execute command."), error);
+            }
+            g_strfreev (argv);
         }
-        g_strfreev (argv);
     }
 }
 
@@ -902,7 +911,7 @@ void file_advrename (GtkMenuItem *menuitem, gpointer not_used)
         {
             main_win->advrename_dlg->set(files);
             gtk_widget_show (*main_win->advrename_dlg);
-            // gdk_window_raise (GTK_WIDGET (main_win->advrename_dlg)->window);     //  FIXME:  bring dlg to top ???
+            // gdk_window_raise (gtk_widget_get_window (GTK_WIDGET (main_win->advrename_dlg)));     //  FIXME:  bring dlg to top ???
         }
 
         g_list_free (files);
@@ -1070,7 +1079,7 @@ void file_exit (GtkMenuItem *menuitem, gpointer not_used)
             break;
 
         default:
-            gdk_window_get_root_origin (GTK_WIDGET (main_win)->window, &x, &y);
+            gdk_window_get_root_origin (gtk_widget_get_window (GTK_WIDGET (main_win)), &x, &y);
             gnome_cmd_data_set_main_win_pos (x, y);
             break;
     }
@@ -1187,7 +1196,7 @@ void command_execute (GtkMenuItem *menuitem, gpointer command)
 	gint argc;
 	gchar **argv;
 	GError *error = nullptr;
-	
+
 	DEBUG ('g', "Running: %s\n", cmd.c_str());
 
 	g_shell_parse_argv (cmd.c_str(), &argc, &argv, nullptr);
@@ -1212,7 +1221,7 @@ void command_open_terminal__internal (GtkMenuItem *menuitem, gpointer not_used)
         command_open_terminal (menuitem, nullptr);
 }
 
-/** 
+/**
  * Executes the command stored in gnome_cmd_data.options.termopen in the
  * active directory.
  */
@@ -1238,14 +1247,14 @@ void command_open_terminal (GtkMenuItem *menuitem, gpointer not_used)
     g_free (dpath);
 }
 
-/** 
+/**
  * Combines the command stored in gnome_cmd_data.options.termopen with a
  * command for a GUI for root login screen. The command is executed in
  * the active directory afterwards.
  */
 void command_open_terminal_as_root (GtkMenuItem *menuitem, gpointer not_used)
 {
-    
+
     int argc = 1;
     char **argv = g_new0 (char *, argc+1);  //initialize argv
     gchar *command;
@@ -1479,7 +1488,7 @@ void mark_compare_directories (GtkMenuItem *menuitem, gpointer not_used)
 
 void view_conbuttons (GtkToggleAction *toggleAction, gpointer not_used)
 {
-    if (!GTK_WIDGET_REALIZED (main_win)) return;
+    if (!gtk_widget_get_realized ( GTK_WIDGET (main_win))) return;
 
     auto active = gtk_toggle_action_get_active(toggleAction);
     g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_DEVBUTTONS, active);
@@ -1488,7 +1497,7 @@ void view_conbuttons (GtkToggleAction *toggleAction, gpointer not_used)
 
 void view_devlist (GtkToggleAction *toggleAction, gpointer not_used)
 {
-    if (!GTK_WIDGET_REALIZED (main_win)) return;
+    if (!gtk_widget_get_realized ( GTK_WIDGET (main_win))) return;
 
     auto active = gtk_toggle_action_get_active(toggleAction);
     g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_DEVLIST, active);
@@ -1497,7 +1506,7 @@ void view_devlist (GtkToggleAction *toggleAction, gpointer not_used)
 
 void view_toolbar (GtkToggleAction *toggleAction, gpointer not_used)
 {
-    if (!GTK_WIDGET_REALIZED (main_win)) return;
+    if (!gtk_widget_get_realized ( GTK_WIDGET (main_win))) return;
 
     auto active = gtk_toggle_action_get_active(toggleAction);
     g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_TOOLBAR, active);
@@ -1506,7 +1515,7 @@ void view_toolbar (GtkToggleAction *toggleAction, gpointer not_used)
 
 void view_buttonbar (GtkToggleAction *toggleAction, gpointer not_used)
 {
-    if (!GTK_WIDGET_REALIZED (main_win)) return;
+    if (!gtk_widget_get_realized ( GTK_WIDGET (main_win))) return;
 
     auto active = gtk_toggle_action_get_active(toggleAction);
     g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_BUTTONBAR, active);
@@ -1515,7 +1524,7 @@ void view_buttonbar (GtkToggleAction *toggleAction, gpointer not_used)
 
 void view_cmdline (GtkToggleAction *toggleAction, gpointer not_used)
 {
-    if (!GTK_WIDGET_REALIZED (main_win)) return;
+    if (!gtk_widget_get_realized ( GTK_WIDGET (main_win))) return;
 
     auto active = gtk_toggle_action_get_active(toggleAction);
     g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_SHOW_CMDLINE, active);
@@ -1530,7 +1539,7 @@ void view_dir_history (GtkMenuItem *menuitem, gpointer not_used)
 
 void view_hidden_files (GtkToggleAction *toggleAction, gpointer not_used)
 {
-    if (!GTK_WIDGET_REALIZED (main_win)) return;
+    if (!gtk_widget_get_realized ( GTK_WIDGET (main_win))) return;
 
     auto active = gtk_toggle_action_get_active(toggleAction);
     g_settings_set_boolean (gcmd_user_actions.settings->filter, GCMD_SETTINGS_FILTER_HIDE_HIDDEN, !active);
@@ -1539,7 +1548,7 @@ void view_hidden_files (GtkToggleAction *toggleAction, gpointer not_used)
 
 void view_backup_files (GtkToggleAction *toggleAction, gpointer not_used)
 {
-    if (!GTK_WIDGET_REALIZED (main_win)) return;
+    if (!gtk_widget_get_realized ( GTK_WIDGET (main_win))) return;
 
     auto active = gtk_toggle_action_get_active(toggleAction);
     g_settings_set_boolean (gcmd_user_actions.settings->filter, GCMD_SETTINGS_FILTER_HIDE_BACKUPS, !active);
@@ -1548,7 +1557,7 @@ void view_backup_files (GtkToggleAction *toggleAction, gpointer not_used)
 
 void view_horizontal_orientation (GtkToggleAction *toggleAction, gpointer not_used)
 {
-    if (!GTK_WIDGET_REALIZED (main_win)) return;
+    if (!gtk_widget_get_realized ( GTK_WIDGET (main_win))) return;
 
     auto active = gtk_toggle_action_get_active(toggleAction);
     g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_HORIZONTAL_ORIENTATION, active);
@@ -1583,7 +1592,7 @@ void view_up (GtkMenuItem *menuitem, gpointer not_used)
 
 void view_main_menu (GtkMenuItem *menuitem, gpointer not_used)
 {
-    if (!GTK_WIDGET_REALIZED (main_win)) return;
+    if (!gtk_widget_get_realized ( GTK_WIDGET (main_win))) return;
 
     gboolean mainmenu_visibility;
     mainmenu_visibility = g_settings_get_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_MAINMENU_VISIBILITY);
@@ -2013,7 +2022,7 @@ void help_problem (GtkMenuItem *menuitem, gpointer not_used)
 {
     GError *error = nullptr;
 
-    if (!gtk_show_uri (nullptr, "https://gitlab.gnome.org/GNOME/gnome-commander/issues", GDK_CURRENT_TIME, &error))
+    if (!gtk_show_uri (nullptr, PACKAGE_BUGREPORT, GDK_CURRENT_TIME, &error))
         gnome_cmd_error_message (_("There was an error reporting problem."), error);
 }
 
@@ -2038,7 +2047,7 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
 
     static const gchar copyright[] = "Copyright \xc2\xa9 2001-2006 Marcus Bjurman\n"
                                      "Copyright \xc2\xa9 2007-2012 Piotr Eljasiak\n"
-                                     "Copyright \xc2\xa9 2013-2022 Uwe Scholz";
+                                     "Copyright \xc2\xa9 2013-2023 Uwe Scholz";
 
     static const gchar comments[] = N_("A fast and powerful file manager for the GNOME desktop");
 
@@ -2061,7 +2070,7 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
 
     gtk_show_about_dialog (*main_win,
                            "name", "GNOME Commander",
-                           "version", VERSION,
+                           "version", PACKAGE_VERSION,
                            "comments", _(comments),
                            "copyright", copyright,
                            "license", license_trans,
@@ -2077,7 +2086,7 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
     g_free (license_trans);
 }
 
-/** 
+/**
  * Parses a command, stored in a char array, and substitutes a certain
  * symbol with path or URI names. The result is stored in a string
  * variable, which is expanded if needed. Possible symbols are:
