@@ -2,7 +2,7 @@
  * @file gnome-cmd-xfer-progress-win.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2022 Uwe Scholz\n
+ * @copyright (C) 2013-2023 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -107,7 +107,7 @@ static void init (GnomeCmdXferProgressWin *win)
     gtk_container_add (GTK_CONTAINER (vbox), bbox);
 
     button = create_stock_button (w, GTK_STOCK_CANCEL, GTK_SIGNAL_FUNC (on_cancel));
-    GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (button, TRUE);
     gtk_container_add (GTK_CONTAINER (bbox), button);
 }
 
@@ -163,12 +163,12 @@ void gnome_cmd_xfer_progress_win_set_total_progress (GnomeCmdXferProgressWin *wi
                                                      guint64 bytes_total)
 {
     gfloat total_prog = bytes_total>0 ? (gdouble) bytes_copied/(gdouble) bytes_total : -1.0f;
-    gtk_progress_set_percentage (GTK_PROGRESS (win->totalprog), total_prog);
+    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (win->totalprog), total_prog);
 
     if (win->fileprog && file_size > 0)
     {
         gfloat file_prog = (gdouble) file_bytes_copied/(gdouble) file_size;
-        gtk_progress_set_percentage (GTK_PROGRESS (win->fileprog), file_prog);
+        gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (win->fileprog), file_prog);
     }
 
     gchar *bytes_total_str = g_strdup (size2string (bytes_total, gnome_cmd_data.options.size_disp_mode));
